use telers::{
    event::{telegram::HandlerResult, EventReturn},
    filters::CommandObject,
    types::Message,
    Bot,
};

use crate::{
    assets::files::UNMUTE_COMMAND_HELP,
    actions::unmute::unmute_member,
    types::{enums::target_user::TargetUser, structs::handler_entity::HandlerEntity},
    utils::{
        general::cast_boxed_array::cast_boxed, 
        telegram::{
            args_parsers::get_user,
            data_getters::get_chat_data, 
            senders::send_html
        },
    },
};

pub async fn unmute(bot: Bot, message: Message, command: CommandObject) -> HandlerResult {
    let (chat_id, mut handler_entity): (i64, HandlerEntity) = get_chat_data(&bot, &message);

    let args: Vec<&'static str> = cast_boxed(command.args);

    let target_user: TargetUser = get_user(
        handler_entity.clone(), 
        args.first().copied(),
        &mut 0,
    );

    if args.is_empty() && !target_user.exist(){
        send_html(bot, message, UNMUTE_COMMAND_HELP).await?; 

        return Ok(EventReturn::Cancel);
    }

    handler_entity
        .message_sender_builder
        .set_text("Нет ID или ответа на сообщение пользователя.");

    unmute_member(handler_entity, chat_id, target_user).await?;

    Ok(EventReturn::Finish)
}
    
